@@ -1761,4 +1761,25 @@ def customer_details(data):
     else:
         logger.info("Client_not_found, 404 client email %s"
                     % apikey)
-        return {"code": 404, "Message": {"response": "User not found"}}
\ No newline at end of file
+        return {"code": 404, "Message": {"response": "User not found"}}
+
+
+def get_plan_details(plan_name):
+    plan = db.get_plan_form_name(plan_name)
+    try:
+        response = {'plan_name': plan_name, 'total': float(plan[3]), 'max_post': plan[5], "images_product": plan[4]}
+    except:
+        response = {}
+    return response
+
+
+def update_plan_admin(plan_name, images_product, max_post, total):
+    plan = db.update_plan(plan_name, images_product, max_post, total)
+    return plan
+
+
+def update_client_payment(customer_name, customer_type, plan_name, status):
+    date = datetime.datetime.today().strftime("%Y-%m-%d %H:%M:%S")
+    plan = db.get_plan_form_name(plan_name)
+    db.update_client_payement(customer_name, customer_type, date, plan_name, status, 'stripe', plan[3])
+    return True
\ No newline at end of file
