@@ -1,7 +1,7 @@
-import datetime, time
+from foqus.cloud_configuration import *
+import datetime
+import time
 import stripe
-import logging
-logger = logging.getLogger(__name__)
 
 
 def create_stripe_customer(ident, email, source):
